// This file is autogenerated. Changes will be overwritten.
#include "PRMOGMWJPH/moc_config.cpp"
#include "PRMOGMWJPH/moc_core.cpp"
#include "PRMOGMWJPH/moc_dbusnotifier.cpp"
#include "PRMOGMWJPH/moc_regionselect.cpp"
#include "PRMOGMWJPH/moc_singleapp.cpp"
#include "H4IQC4G222/moc_about.cpp"
#include "H4IQC4G222/moc_configwidget.cpp"
#include "H4IQC4G222/moc_mainwindow.cpp"
#include "AAQQQ6ILXV/moc_ScreenCopy.cpp"
#include "AAQQQ6ILXV/moc_ScreenShot.cpp"
